"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Maybe = void 0;
/**
 * Maybe Monad for handling nullable values in a safe way.
 */
var Maybe = /** @class */ (function () {
    /**
     * @param value Nullable value which could be null or T.
     */
    function Maybe(value) {
        this.value = value;
    }
    /**
     * Returns a new Maybe instance containing the given value.
     * @param value Non-nullable value.
     */
    Maybe.just = function (value) {
        return new Maybe(value);
    };
    /**
     * Returns a new Maybe instance representing a missing value.
     */
    Maybe.nothing = function () {
        return new Maybe(null);
    };
    /**
     * Checks if the Maybe is equal to another Maybe.
     * @param other The other Maybe to compare with.
     * @param equalityFn A function that checks equality between the underlying values of two Maybes.
     */
    Maybe.prototype.equals = function (other, equalityFn) {
        if (equalityFn === void 0) { equalityFn = function (a, b) { return a === b; }; }
        return (this.isJust() === other.isJust() &&
            (this.isNothing() || equalityFn(this.value, other.value)));
    };
    /**
     * Applies a function to the Maybe's value if it exists, otherwise does nothing. The function should return another Maybe.
     * @param fn Function to apply to the Maybe's value.
     */
    Maybe.prototype.flatMap = function (fn) {
        return this.isNothing() ? Maybe.nothing() : fn(this.value);
    };
    /**
     * Invokes the appropriate function depending on whether the Maybe is a Just or a Nothing.
     * @param whenNothing Function to invoke if the Maybe is a Nothing.
     * @param whenJust Function to invoke if the Maybe is a Just.
     */
    Maybe.prototype.fold = function (whenNothing, whenJust) {
        return this.isNothing() ? whenNothing() : whenJust(this.value);
    };
    /**
     * Returns the contained value if the Maybe is a Just. If the Maybe is a Nothing, returns the provided default value.
     * @param defaultValue Default value to return if the Maybe is a Nothing.
     */
    Maybe.prototype.getOrElse = function (defaultValue) {
        return this.isJust() ? this.value : defaultValue;
    };
    /**
     * Returns the contained value if the Maybe is a Just. If the Maybe is a Nothing, throws the provided error.
     * @param error Error to throw if the Maybe is a Nothing.
     */
    Maybe.prototype.getOrElseThrow = function (error) {
        if (this.isNothing()) {
            throw error;
        }
        return this.value;
    };
    /**
     * Returns true if the Maybe contains a value, false otherwise.
     */
    Maybe.prototype.isJust = function () {
        return this.value !== null;
    };
    /**
     * Returns true if the Maybe does not contain a value (i.e., it's Nothing), false otherwise.
     */
    Maybe.prototype.isNothing = function () {
        return !this.isJust();
    };
    /**
     * Transforms the value contained in the Maybe if it exists, otherwise does nothing.
     * @param fn Function to transform the contained value.
     */
    Maybe.prototype.map = function (fn) {
        return this.isNothing()
            ? Maybe.nothing()
            : Maybe.just(fn(this.value));
    };
    /**
     * Returns the Maybe itself if it contains a value, otherwise returns a Maybe containing the provided default value.
     * @param defaultValue Default value to be wrapped in a Maybe if the original Maybe is a Nothing.
     */
    Maybe.prototype.orDefault = function (defaultValue) {
        return this.isNothing() ? Maybe.just(defaultValue) : this;
    };
    /**
     * Returns the Maybe itself if it contains a value, otherwise returns the provided Maybe.
     * @param other Another Maybe to be returned if the original Maybe is a Nothing.
     */
    Maybe.prototype.orJust = function (other) {
        return this.isJust() ? this : other;
    };
    /**
     * Returns the value if it exists, otherwise returns null.
     */
    Maybe.prototype.toNullable = function () {
        return this.value;
    };
    /**
     * Returns a string representation of the Maybe.
     */
    Maybe.prototype.toString = function () {
        return this.isJust() ? "Just(".concat(this.value, ")") : "Nothing";
    };
    return Maybe;
}());
exports.Maybe = Maybe;
//# sourceMappingURL=maybe.js.map