/**
 * Invokes the given function with the provided value and returns the value. Use it to perform intermediate operations in a method chain.
 */
declare function tap(value: unknown, interceptor: Function): unknown;
/**
 * Executes the given function with the provided value and returns the result. Use it to perform a sequence of operations in a method chain.
 */
declare function thru(value: unknown, interceptor: Function): unknown;
/**
 * Copies the enumerable properties of the source object(s) to the destination object.
 */
declare function assign<T extends object>(target: T, ...sources: object[]): T;
/**
 * Copies the enumerable and inherited properties of the source object(s) to the destination object.
 */
declare function assignIn<T extends object>(target: T, ...sources: object[]): T;
/**
 * This method is like `assignIn` except that it accepts a customizer which is invoked to produce the assigned values.
 */
declare function assignInWith<T extends object>(target: T, ...sources: object[]): T;
/**
 * This method is like `assign` except that it accepts a customizer which is invoked to produce the assigned values.
 */
declare function assignWith<T extends object>(target: T, ...sources: object[]): T;
/**
 * Creates an array of values corresponding to paths of the object.
 */
declare function valueAt(object: {
    [key: string]: unknown;
}, paths: string[], separator?: string): unknown[];
/**
 * Creates a new object with the specified prototype object and properties.
 */
declare function create(prototype: null | object, properties?: PropertyDescriptorMap): object;
/**
 * Assigns default properties of the source objects to the destination object.
 */
declare function defaults<T extends object>(object: T, ...sources: object[]): T;
/**
 * This method is like `defaults` except that it recursively assigns default properties.
 */
declare function defaultsDeep<T extends object>(object: T, ...sources: object[]): T;
/**
 * This method returns the key of the first element predicate returns truthy for.
 */
declare function findKey<T>(object: Record<string, T>, predicate: (value: T, key: string) => boolean): string | undefined;
/**
 * This method returns the key of the last element predicate returns truthy for.
 */
declare function findLastKey<T>(object: Record<string, T>, predicate: (value: T, key: string) => boolean): string | undefined;
/**
 * Iterates over own and inherited enumerable string keyed properties of an object, invoking `iteratee` for each property.
 */
declare function forIn<T extends object>(object: T, iteratee: (value: unknown, key: string) => void): T;
/**
 * This method is like `forIn` except that it iterates over properties in reverse order.
 */
declare function forInRight<T extends object>(object: T, iteratee: (value: unknown, key: string) => void): T;
/**
 * Iterates over own enumerable string keyed properties of an object, invoking `iteratee` for each property.
 */
declare function forOwn<T extends object>(object: T, iteratee: (value: unknown, key: string) => void): T;
/**
 * This method is like `forOwn` except that it iterates over properties in reverse order.
 */
declare function forOwnRight<T extends object>(object: T, iteratee: (value: unknown, key: string) => void): T;
/**
 * Creates an array of function property names from own enumerable properties of `object`.
 */
declare function functions(object: object): string[];
/**
 * Creates an array of function property names from own and inherited enumerable properties of `object`.
 */
declare function functionsIn(object: object): string[];
/**
 * Gets the value at `path` of `object`.
 */
declare function get(object: object, path: string | string[], defaultValue?: unknown, separator?: string): unknown;
/**
 * Checks if `path` is a direct property of `object`.
 */
declare function has(object: object, path: string | string[], separator?: string): boolean;
/**
 * Creates an object composed of the inverted keys and values of `object`.
 */
declare function invert(object: Record<string, string>): Record<string, string>;
/**
 * This method is like `invert` except that it group the inverted values by iteratee.
 */
declare function invertBy<T extends Record<string, unknown>>(object: T, iteratee: (value: unknown) => string): Record<string, string[]>;
/**
 * Invokes the method at `path` of `object`.
 */
declare function invoke(object: object, path: string | string[], ...args: unknown[]): unknown;
/**
 * Creates an array of the own enumerable property names of `object`.
 */
declare function keys(object: object): string[];
/**
 * Creates an array of the own and inherited enumerable property names of `object`.
 */
declare function keysIn(object: object): string[];
/**
 * Creates an object with the same keys as `object` and values generated by running each own enumerable string keyed property of `object` through `iteratee`.
 */
declare function mapKeys(object: Record<string, unknown>, iteratee: (value: unknown, key: string) => string): Record<string, unknown>;
/**
 * Creates an object with the same keys as `object` and values generated by running each own enumerable string keyed property of `object` through `iteratee`.
 */
declare function mapValues(object: Record<string, unknown>, iteratee: (value: unknown, key: string) => unknown): Record<string, unknown>;
/**
 * Recursively merges own and inherited enumerable string keyed properties of source objects into the destination object.
 */
declare function merge<T extends object>(object: T, ...sources: object[]): T;
/**
 * This method is like `merge` except that it accepts a customizer which is invoked to produce the merged values.
 */
declare function mergeWith<T extends object>(object: T, ...sources: object[]): T;
/**
 * Creates an object composed of the object properties omitted based on the given keys.
 */
declare function omit(object: Record<string, unknown>, keys: string[]): Record<string, unknown>;
/**
 * Creates an object composed of the object properties omitted based on the given predicate.
 */
declare function omitBy(object: Record<string, unknown>, predicate: (value: unknown, key: string) => boolean): Record<string, unknown>;
/**
 * Creates an object composed of the picked object properties.
 */
declare function pick(object: Record<string, unknown>, keys: string[]): Record<string, unknown>;
/**
 * Creates an object composed of the object properties picked based on the given predicate.
 */
declare function pickBy(object: Record<string, unknown>, predicate: (value: unknown, key: string) => boolean): Record<string, unknown>;
/**
 * Gets the value at `path` of `object`. If the resolved value is a function, it's invoked with the `this` binding of its parent object and its result is returned.
 */
declare function result(object: object, path: string | string[], defaultValue?: unknown): unknown;
/**
 * Sets the value at `path` of `object`. If a portion of `path` doesn't exist, it's created.
 */
declare function set(object: Record<string, unknown>, path: string | string[], value: unknown, separator?: string): Record<string, unknown>;
/**
 * This method is like `set` except that it accepts a customizer which is invoked to produce the object of path.
 */
declare function setWith(object: Record<string, unknown>, path: string | string[], value: unknown, customizer: (nsValue: unknown, key: string, nsObject: Record<string, unknown>) => unknown, separator?: string): Record<string, unknown>;
/**
 * Creates an array of own enumerable string keyed-value pairs for `object`.
 */
declare function toPairs(object: object): [string, unknown][];
/**
 * Creates an array of own and inherited enumerable string keyed-value pairs for `object`.
 */
declare function toPairsIn(object: {
    [key: string]: unknown;
}): [string, unknown][];
/**
 * Recursively merges own enumerable string keyed properties of source objects into the destination object.
 */
declare function transform<T extends object>(object: T, iteratee: (accumulator: T, value: unknown, key: string, object: T) => boolean | void, accumulator?: T): T;
/**
 * Removes the property at `path` of `object`.
 */
declare function unset(object: Record<string, unknown>, path: string | string[], separator?: string): boolean;
/**
 * This method is like `set` except that it accepts a updater to produce the value to set.
 */
declare function update(object: Record<string, unknown>, path: string | string[], updater: (value: unknown) => unknown): object;
/**
 * This method is like `update` except that it accepts a customizer which is invoked to produce the value to set.
 */
declare function updateWith(object: Record<string, unknown>, path: string | string[], updater: (value: unknown, key: string, nsObject: object) => unknown, customizer: (nsValue: unknown, key: string, nsObject: object) => unknown): object;
/**
 * Creates an array of the own enumerable string keyed property values of `object`.
 */
declare function values(object: object): unknown[];
/**
 * Creates an array of the own and inherited enumerable string keyed property values of `object`.
 */
declare function valuesIn<T>(object: T): unknown[];
/**
 * Flattens an object. This function can also handle objects that have child objects.
 * Child objects are retrieved using the provided `getChildren` function.
 * The resulting array contains all objects and their children in a flat structure.
 * @param rootObject - The root object to be flattened.
 * @param getChildren - A function that, given an object, returns its child objects or undefined.
 * @returns A flat array containing the root object and its child objects.
 */
declare function flattenObject(rootObject: Record<string, unknown>, getChildren: ((item: Record<string, unknown>) => Record<string, unknown>[] | undefined) | undefined): Record<string, unknown>[];
declare function bindAll(object: Record<string, unknown>, ...methodNames: string[]): void;
declare function cond(pairs: [Function, Function][]): (...args: unknown[]) => unknown;
declare function conforms(source: Record<string, (value: unknown) => boolean>): (object: Record<string, unknown>) => boolean;
declare function constant(value: unknown): Function;
declare function flow(...funcs: Function[]): Function;
declare function flowRight(...funcs: Function[]): Function;
declare function identity(value: unknown): unknown;
declare function iteratee(path: string | string[], separator?: string): (object: Record<string, unknown>) => unknown;
declare function matches(source: Record<string, unknown>): (object: Record<string, unknown>) => boolean;
declare function matchesProperty(path: string | string[], value: unknown): (object: Record<string, unknown>) => boolean;
declare function method(path: string | string[], ...args: unknown[]): (object: Record<string, unknown>) => unknown;
declare function methodOf(object: Record<string, unknown>, ...args: unknown[]): (path: string | string[]) => unknown;
declare function mixin<T extends Record<string, unknown>>(object: T, ...sources: T[]): T;
declare function nthArg(n?: number): Function;
declare function over(...iteratees: Function[]): Function;
declare function overEvery(...predicates: Function[]): Function;
declare function overSome(...predicates: Function[]): Function;
declare function property(path: string | string[]): (object: Record<string, unknown>) => unknown;
declare function propertyOf(object: Record<string, unknown>): (path: string | string[]) => unknown;
declare function range(start: number, end?: number, step?: number): number[];
declare function rangeRight(start: number, end?: number, step?: number): number[];
declare function runInContext(context: object): Function;
declare function stubFunction(): () => undefined;
declare function stubArray(): unknown[];
declare function stubFalse(): boolean;
declare function stubObject(): object;
declare function stubString(value?: string): string;
declare function stubTrue(): boolean;
declare function times(n: number, iteratee: (index: number) => unknown): unknown[];
declare function toPath(value: string | string[], separator?: string): string[];
declare function uniqueId(): string;
declare function unixTimestamp(date?: number): number;
declare function getType(val: unknown): string;
declare function deepEqual(a: unknown, b: unknown): boolean;
declare function shallowEqual(a: unknown, b: unknown): boolean;
export { assign, assignIn, assignInWith, assignWith, bindAll, cond, conforms, constant, create, deepEqual, defaults, defaultsDeep, findKey, findLastKey, flattenObject, flow, flowRight, forIn, forInRight, forOwn, forOwnRight, functions, functionsIn, get, getType, has, identity, invert, invertBy, invoke, iteratee, keys, keysIn, mapKeys, mapValues, matches, matchesProperty, merge, mergeWith, method, methodOf, mixin, nthArg, omit, omitBy, over, overEvery, overSome, pick, pickBy, property, propertyOf, range, rangeRight, result, runInContext, set, setWith, shallowEqual, stubArray, stubFalse, stubFunction, stubObject, stubString, stubTrue, tap, thru, times, toPairs, toPairsIn, toPath, transform, uniqueId, unixTimestamp, unset, update, updateWith, valueAt, values, valuesIn, };
//# sourceMappingURL=object-utilities.d.ts.map